[][src]Enum pallet_timestamp::Call

pub enum Call<T: Trait> {
    set(T::Moment),
    // some variants omitted
}

Dispatchable calls.

Each variant of this enum maps to a dispatchable function from the associated module.

Variants

set(T::Moment)

Set the current time.

This call should be invoked exactly once per block. It will panic at the finalization phase, if this call hasn't been invoked by that time.

The timestamp should be greater than the previous one by the amount specified by MinimumPeriod.

The dispatch origin for this call must be Inherent.